module.exports = {
	root: true,
	env: {
		browser: true,
		es6: true,
		node: true
	},
	ignorePatterns: ["node_modules/", "**/coverage/*", "**/dist/*", "**/types/*", "**/__mocks__/*", "**/*.vue", "**/*.d.ts", "**/*.js"],
	parser: "@typescript-eslint/parser",
	parserOptions: {
		project: "./tsconfig.json"
	},
	plugins: [
		"@typescript-eslint"
	],
	extends: [
		"airbnb-typescript/base"
	],
	rules: {
		// maximum line length
		'max-len': ['error', { code: 180, tabWidth: 2 }],
		// allow console.log only in development
		"no-console": process.env.NODE_ENV === "production" ? "warn" : "off",
		// allow debugger only in development
		"no-debugger": process.env.NODE_ENV === "production" ? "warn" : "off",
		// allow functions to be used before their definition
		'@typescript-eslint/no-use-before-define': ['error', {functions: false}],
		// don't check classes are exported using default when there is only one export
		'import/prefer-default-export': 'off',
		// allow changes in properties of parameters
		'no-param-reassign': ['error', {props: false}],
		// allow circular import references,
		'import/no-cycle': 'off',
		// allow class methos without this
		'class-methods-use-this': 'off',
		// ignore error caused by monorepo and path aliases
		'import/no-unresolved': 'off',
		// ignore enforcement of consistent linebreak style
		'linebreak-style': 0,
		// team development preference
		'@typescript-eslint/indent': 0,
		'no-tabs': 0,
		"@typescript-eslint/no-explicit-any": 0,
		'no-useless-catch': 0,
		'object-curly-newline': 0,
		"import/extensions": "off",
		"import/no-extraneous-dependencies": "off",
		"@typescript-eslint/no-empty-function": "off",
		"warnOnUnsupportedTypeScriptVersion": 0,
	}
}
