import { DialogService } from '@zeedhi/common';
import { I18n } from '@zeedhi/core';
import { AxiosError } from 'axios';
import { MessageServices } from '../Support/MessageServices';
import { AuthService } from '../Authentication/AuthService';

export class AddResponseFail {
    /**
     * Error code 100 = invalid token
     * Error code 101 = expired token
     */
    public static libInvalidToken(error: AxiosError, errorCode: number) {
        if (errorCode === 100) {
            AuthService.getInstance().logout();
        } else if (errorCode === 101) {
            MessageServices.showMessage('ALE_EXPIRED_SESSION', {}, 'warning', AddResponseFail.buttonOkLogout());
        }
    }

    public static libInvalidTokenSupportOperator() {
        MessageServices.showMessage('ALE_EXPIRED_SESSION_SUPPORT_OPERATOR', {}, 'warning', AddResponseFail.buttonOkLogout());
    }

    public static libConcurrentAccess() {
        MessageServices.showMessage('ALE_SESSION_WILL_BE_ENDED', {}, 'warning', AddResponseFail.buttonOkLogout());
    }

    private static buttonOkLogout() {
        return [
            {
                name: 'ok',
                component: 'ZdButton',
                label: I18n.translate('OK'),
                events: {
                    click: (() => {
                        DialogService.hide();
                        AuthService.getInstance().logout();
                    }),
                },
            },
        ];
    }
}
